Rules
=====

When linting a document with yamllint, a series of rules (such as
``line-length``, ``trailing-spaces``, etc.) are checked against.

A :doc:`configuration file <configuration>` can be used to enable or disable
these rules, to set their level (*error* or *warning*), but also to tweak their
options.

This page describes the rules and their options.

.. contents:: List of rules
   :local:
   :depth: 1

braces
------

.. automodule:: yamllint.rules.braces

brackets
--------

.. automodule:: yamllint.rules.brackets

colons
------

.. automodule:: yamllint.rules.colons

commas
------

.. automodule:: yamllint.rules.commas

comments
--------

.. automodule:: yamllint.rules.comments

comments-indentation
--------------------

.. automodule:: yamllint.rules.comments_indentation

document-end
------------

.. automodule:: yamllint.rules.document_end

document-start
--------------

.. automodule:: yamllint.rules.document_start

empty-lines
-----------

.. automodule:: yamllint.rules.empty_lines

empty-values
------------

.. automodule:: yamllint.rules.empty_values

float-values
------------

.. automodule:: yamllint.rules.float_values


hyphens
-------

.. automodule:: yamllint.rules.hyphens

indentation
-----------

.. automodule:: yamllint.rules.indentation

key-duplicates
--------------

.. automodule:: yamllint.rules.key_duplicates

key-ordering
--------------

.. automodule:: yamllint.rules.key_ordering

line-length
-----------

.. automodule:: yamllint.rules.line_length

new-line-at-end-of-file
-----------------------

.. automodule:: yamllint.rules.new_line_at_end_of_file

new-lines
---------

.. automodule:: yamllint.rules.new_lines

octal-values
------------

.. automodule:: yamllint.rules.octal_values

quoted-strings
--------------

.. automodule:: yamllint.rules.quoted_strings

trailing-spaces
---------------

.. automodule:: yamllint.rules.trailing_spaces

truthy
---------------

.. automodule:: yamllint.rules.truthy
